Neads
=====

Neads is a modular tool for modelling of dynamical systems with complex 
internal structure by complex networks. The library is able to automatically 
configure various parametrized analytical pipelines, it allows executing all 
potential runs and comparing their results. Also, it stores intermediate 
results and makes them available for acceleration of subsequent calculations 
as well as potential pipelines extensions. This tool is suitable for analysing 
many real-world systems including the human brain, financial systems or social 
networks.

Install
-------

Install Neads via :code:`pip`::

    $ pip install neads

Bugs
----

Please report any bugs you find `here <https://github.com/thrayld/neads/issues>`_.
